summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
Diffstat (limited to 'sys')
-rw-r--r--sys/amd64/amd64/fpu.c3
-rw-r--r--sys/amd64/amd64/tsc.c1
-rw-r--r--sys/amd64/isa/clock.c1
-rw-r--r--sys/amd64/isa/intr_machdep.c1
-rw-r--r--sys/amd64/isa/isa_dma.c1
-rw-r--r--sys/amd64/isa/nmi.c1
-rw-r--r--sys/amd64/isa/npx.c3
-rw-r--r--sys/dev/atkbdc/atkbdc_isa.c1
-rw-r--r--sys/dev/atkbdc/atkbdc_subr.c1
-rw-r--r--sys/dev/fdc/fdc.c1
-rw-r--r--sys/dev/joy/joy.c1
-rw-r--r--sys/dev/ppc/ppc.c1
-rw-r--r--sys/dev/sio/sio.c1
-rw-r--r--sys/dev/speaker/spkr.c1
-rw-r--r--sys/i386/i386/tsc.c1
-rw-r--r--sys/i386/isa/clock.c1
-rw-r--r--sys/i386/isa/intr_machdep.c1
-rw-r--r--sys/i386/isa/isa_dma.c1
-rw-r--r--sys/i386/isa/nmi.c1
-rw-r--r--sys/i386/isa/npx.c3
-rw-r--r--sys/i386/isa/spkr.c1
-rw-r--r--sys/isa/atkbdc_isa.c1
-rw-r--r--sys/isa/atrtc.c1
-rw-r--r--sys/isa/fd.c1
-rw-r--r--sys/isa/joy.c1
-rw-r--r--sys/isa/ppc.c1
-rw-r--r--sys/isa/sio.c1
27 files changed, 30 insertions, 3 deletions
diff --git a/sys/amd64/amd64/tsc.c b/sys/amd64/amd64/tsc.c
index a67e1ee..e0a638e 100644
--- a/sys/amd64/amd64/tsc.c
+++ b/sys/amd64/amd64/tsc.c
@@ -1279,3 +1279,4 @@ static driver_t attimer_driver = {
static devclass_t attimer_devclass;
DRIVER_MODULE(attimer, isa, attimer_driver, attimer_devclass, 0, 0);
+DRIVER_MODULE(attimer, acpi, attimer_driver, attimer_devclass, 0, 0);
diff --git a/sys/amd64/isa/clock.c b/sys/amd64/isa/clock.c
index a67e1ee..e0a638e 100644
--- a/sys/amd64/isa/clock.c
+++ b/sys/amd64/isa/clock.c
@@ -1279,3 +1279,4 @@ static driver_t attimer_driver = {
static devclass_t attimer_devclass;
DRIVER_MODULE(attimer, isa, attimer_driver, attimer_devclass, 0, 0);
+DRIVER_MODULE(attimer, acpi, attimer_driver, attimer_devclass, 0, 0);
diff --git a/sys/amd64/isa/intr_machdep.c b/sys/amd64/isa/intr_machdep.c
index 48555d3..5c4da72 100644
--- a/sys/amd64/isa/intr_machdep.c
+++ b/sys/amd64/isa/intr_machdep.c
@@ -211,6 +211,7 @@ static driver_t atpic_driver = {
static devclass_t atpic_devclass;
DRIVER_MODULE(atpic, isa, atpic_driver, atpic_devclass, 0, 0);
+DRIVER_MODULE(atpic, acpi, atpic_driver, atpic_devclass, 0, 0);
/*
* Handle a NMI, possibly a machine check.
diff --git a/sys/amd64/isa/isa_dma.c b/sys/amd64/isa/isa_dma.c
index d9f1233..38ab398 100644
--- a/sys/amd64/isa/isa_dma.c
+++ b/sys/amd64/isa/isa_dma.c
@@ -549,3 +549,4 @@ static driver_t atdma_driver = {
static devclass_t atdma_devclass;
DRIVER_MODULE(atdma, isa, atdma_driver, atdma_devclass, 0, 0);
+DRIVER_MODULE(atdma, acpi, atdma_driver, atdma_devclass, 0, 0);
diff --git a/sys/amd64/isa/nmi.c b/sys/amd64/isa/nmi.c
index 48555d3..5c4da72 100644
--- a/sys/amd64/isa/nmi.c
+++ b/sys/amd64/isa/nmi.c
@@ -211,6 +211,7 @@ static driver_t atpic_driver = {
static devclass_t atpic_devclass;
DRIVER_MODULE(atpic, isa, atpic_driver, atpic_devclass, 0, 0);
+DRIVER_MODULE(atpic, acpi, atpic_driver, atpic_devclass, 0, 0);
/*
* Handle a NMI, possibly a machine check.
diff --git a/sys/dev/atkbdc/atkbdc_isa.c b/sys/dev/atkbdc/atkbdc_isa.c
index 2685164..ce72f05 100644
--- a/sys/dev/atkbdc/atkbdc_isa.c
+++ b/sys/dev/atkbdc/atkbdc_isa.c
@@ -313,3 +313,4 @@ atkbdc_write_ivar(device_t bus, device_t dev, int index, uintptr_t val)
}
DRIVER_MODULE(atkbdc, isa, atkbdc_driver, atkbdc_devclass, 0, 0);
+DRIVER_MODULE(atkbdc, acpi, atkbdc_driver, atkbdc_devclass, 0, 0);
diff --git a/sys/dev/atkbdc/atkbdc_subr.c b/sys/dev/atkbdc/atkbdc_subr.c
index 2685164..ce72f05 100644
--- a/sys/dev/atkbdc/atkbdc_subr.c
+++ b/sys/dev/atkbdc/atkbdc_subr.c
@@ -313,3 +313,4 @@ atkbdc_write_ivar(device_t bus, device_t dev, int index, uintptr_t val)
}
DRIVER_MODULE(atkbdc, isa, atkbdc_driver, atkbdc_devclass, 0, 0);
+DRIVER_MODULE(atkbdc, acpi, atkbdc_driver, atkbdc_devclass, 0, 0);
diff --git a/sys/dev/fdc/fdc.c b/sys/dev/fdc/fdc.c
index 55634f3..f896b33 100644
--- a/sys/dev/fdc/fdc.c
+++ b/sys/dev/fdc/fdc.c
@@ -1067,6 +1067,7 @@ static driver_t fdc_driver = {
};
DRIVER_MODULE(fdc, isa, fdc_driver, fdc_devclass, 0, 0);
+DRIVER_MODULE(fdc, acpi, fdc_driver, fdc_devclass, 0, 0);
#if NCARD > 0
diff --git a/sys/dev/joy/joy.c b/sys/dev/joy/joy.c
index 55ff62c..77d35c5 100644
--- a/sys/dev/joy/joy.c
+++ b/sys/dev/joy/joy.c
@@ -156,6 +156,7 @@ static driver_t joy_isa_driver = {
};
DRIVER_MODULE(joy, isa, joy_isa_driver, joy_devclass, 0, 0);
+DRIVER_MODULE(joy, acpi, joy_isa_driver, joy_devclass, 0, 0);
static int
joyopen(dev_t dev, int flags, int fmt, struct proc *p)
diff --git a/sys/dev/ppc/ppc.c b/sys/dev/ppc/ppc.c
index 099cd79..c36b982 100644
--- a/sys/dev/ppc/ppc.c
+++ b/sys/dev/ppc/ppc.c
@@ -2162,3 +2162,4 @@ ppc_teardown_intr(device_t bus, device_t child, struct resource *r, void *ih)
}
DRIVER_MODULE(ppc, isa, ppc_driver, ppc_devclass, 0, 0);
+DRIVER_MODULE(ppc, acpi, ppc_driver, ppc_devclass, 0, 0);
diff --git a/sys/dev/sio/sio.c b/sys/dev/sio/sio.c
index 67ef253..5bbd931 100644
--- a/sys/dev/sio/sio.c
+++ b/sys/dev/sio/sio.c
@@ -3373,6 +3373,7 @@ siogdbputc(c)
#endif
DRIVER_MODULE(sio, isa, sio_isa_driver, sio_devclass, 0, 0);
+DRIVER_MODULE(sio, acpi, sio_isa_driver, sio_devclass, 0, 0);
#if NCARD > 0
DRIVER_MODULE(sio, pccard, sio_pccard_driver, sio_devclass, 0, 0);
#endif
diff --git a/sys/dev/speaker/spkr.c b/sys/dev/speaker/spkr.c
index ad9dc3e..0fadea8 100644
--- a/sys/dev/speaker/spkr.c
+++ b/sys/dev/speaker/spkr.c
@@ -637,5 +637,6 @@ static driver_t atspeaker_driver = {
static devclass_t atspeaker_devclass;
DRIVER_MODULE(atspeaker, isa, atspeaker_driver, atspeaker_devclass, 0, 0);
+DRIVER_MODULE(atspeaker, acpi, atspeaker_driver, atspeaker_devclass, 0, 0);
/* spkr.c ends here */
diff --git a/sys/i386/i386/tsc.c b/sys/i386/i386/tsc.c
index a67e1ee..e0a638e 100644
--- a/sys/i386/i386/tsc.c
+++ b/sys/i386/i386/tsc.c
@@ -1279,3 +1279,4 @@ static driver_t attimer_driver = {
static devclass_t attimer_devclass;
DRIVER_MODULE(attimer, isa, attimer_driver, attimer_devclass, 0, 0);
+DRIVER_MODULE(attimer, acpi, attimer_driver, attimer_devclass, 0, 0);
diff --git a/sys/i386/isa/clock.c b/sys/i386/isa/clock.c
index a67e1ee..e0a638e 100644
--- a/sys/i386/isa/clock.c
+++ b/sys/i386/isa/clock.c
@@ -1279,3 +1279,4 @@ static driver_t attimer_driver = {
static devclass_t attimer_devclass;
DRIVER_MODULE(attimer, isa, attimer_driver, attimer_devclass, 0, 0);
+DRIVER_MODULE(attimer, acpi, attimer_driver, attimer_devclass, 0, 0);
diff --git a/sys/i386/isa/intr_machdep.c b/sys/i386/isa/intr_machdep.c
index 48555d3..5c4da72 100644
--- a/sys/i386/isa/intr_machdep.c
+++ b/sys/i386/isa/intr_machdep.c
@@ -211,6 +211,7 @@ static driver_t atpic_driver = {
static devclass_t atpic_devclass;
DRIVER_MODULE(atpic, isa, atpic_driver, atpic_devclass, 0, 0);
+DRIVER_MODULE(atpic, acpi, atpic_driver, atpic_devclass, 0, 0);
/*
* Handle a NMI, possibly a machine check.
diff --git a/sys/i386/isa/isa_dma.c b/sys/i386/isa/isa_dma.c
index d9f1233..38ab398 100644
--- a/sys/i386/isa/isa_dma.c
+++ b/sys/i386/isa/isa_dma.c
@@ -549,3 +549,4 @@ static driver_t atdma_driver = {
static devclass_t atdma_devclass;
DRIVER_MODULE(atdma, isa, atdma_driver, atdma_devclass, 0, 0);
+DRIVER_MODULE(atdma, acpi, atdma_driver, atdma_devclass, 0, 0);
diff --git a/sys/i386/isa/nmi.c b/sys/i386/isa/nmi.c
index 48555d3..5c4da72 100644
--- a/sys/i386/isa/nmi.c
+++ b/sys/i386/isa/nmi.c
@@ -211,6 +211,7 @@ static driver_t atpic_driver = {
static devclass_t atpic_devclass;
DRIVER_MODULE(atpic, isa, atpic_driver, atpic_devclass, 0, 0);
+DRIVER_MODULE(atpic, acpi, atpic_driver, atpic_devclass, 0, 0);
/*
* Handle a NMI, possibly a machine check.
diff --git a/sys/i386/isa/spkr.c b/sys/i386/isa/spkr.c
index ad9dc3e..0fadea8 100644
--- a/sys/i386/isa/spkr.c
+++ b/sys/i386/isa/spkr.c
@@ -637,5 +637,6 @@ static driver_t atspeaker_driver = {
static devclass_t atspeaker_devclass;
DRIVER_MODULE(atspeaker, isa, atspeaker_driver, atspeaker_devclass, 0, 0);
+DRIVER_MODULE(atspeaker, acpi, atspeaker_driver, atspeaker_devclass, 0, 0);
/* spkr.c ends here */
diff --git a/sys/isa/atkbdc_isa.c b/sys/isa/atkbdc_isa.c
index 2685164..ce72f05 100644
--- a/sys/isa/atkbdc_isa.c
+++ b/sys/isa/atkbdc_isa.c
@@ -313,3 +313,4 @@ atkbdc_write_ivar(device_t bus, device_t dev, int index, uintptr_t val)
}
DRIVER_MODULE(atkbdc, isa, atkbdc_driver, atkbdc_devclass, 0, 0);
+DRIVER_MODULE(atkbdc, acpi, atkbdc_driver, atkbdc_devclass, 0, 0);
diff --git a/sys/isa/atrtc.c b/sys/isa/atrtc.c
index a67e1ee..e0a638e 100644
--- a/sys/isa/atrtc.c
+++ b/sys/isa/atrtc.c
@@ -1279,3 +1279,4 @@ static driver_t attimer_driver = {
static devclass_t attimer_devclass;
DRIVER_MODULE(attimer, isa, attimer_driver, attimer_devclass, 0, 0);
+DRIVER_MODULE(attimer, acpi, attimer_driver, attimer_devclass, 0, 0);
diff --git a/sys/isa/fd.c b/sys/isa/fd.c
index 55634f3..f896b33 100644
--- a/sys/isa/fd.c
+++ b/sys/isa/fd.c
@@ -1067,6 +1067,7 @@ static driver_t fdc_driver = {
};
DRIVER_MODULE(fdc, isa, fdc_driver, fdc_devclass, 0, 0);
+DRIVER_MODULE(fdc, acpi, fdc_driver, fdc_devclass, 0, 0);
#if NCARD > 0
diff --git a/sys/isa/joy.c b/sys/isa/joy.c
index 55ff62c..77d35c5 100644
--- a/sys/isa/joy.c
+++ b/sys/isa/joy.c
@@ -156,6 +156,7 @@ static driver_t joy_isa_driver = {
};
DRIVER_MODULE(joy, isa, joy_isa_driver, joy_devclass, 0, 0);
+DRIVER_MODULE(joy, acpi, joy_isa_driver, joy_devclass, 0, 0);
static int
joyopen(dev_t dev, int flags, int fmt, struct proc *p)
diff --git a/sys/isa/ppc.c b/sys/isa/ppc.c
index 099cd79..c36b982 100644
--- a/sys/isa/ppc.c
+++ b/sys/isa/ppc.c
@@ -2162,3 +2162,4 @@ ppc_teardown_intr(device_t bus, device_t child, struct resource *r, void *ih)
}
DRIVER_MODULE(ppc, isa, ppc_driver, ppc_devclass, 0, 0);
+DRIVER_MODULE(ppc, acpi, ppc_driver, ppc_devclass, 0, 0);
diff --git a/sys/isa/sio.c b/sys/isa/sio.c
index 67ef253..5bbd931 100644
--- a/sys/isa/sio.c
+++ b/sys/isa/sio.c
@@ -3373,6 +3373,7 @@ siogdbputc(c)
#endif
DRIVER_MODULE(sio, isa, sio_isa_driver, sio_devclass, 0, 0);
+DRIVER_MODULE(sio, acpi, sio_isa_driver, sio_devclass, 0, 0);
#if NCARD > 0
DRIVER_MODULE(sio, pccard, sio_pccard_driver, sio_devclass, 0, 0);
#endif
OpenPOWER on IntegriCloud
diff --git a/sys/amd64/amd64/fpu.c b/sys/amd64/amd64/fpu.c
index a246f30..4fe3d04 100644
--- a/sys/amd64/amd64/fpu.c
+++ b/sys/amd64/amd64/fpu.c
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
* This sucks up the legacy ISA support assignments from PNPBIOS.
*/
static struct isa_pnp_id npxisa_ids[] = {
{ 0x040cd041, "Legacy ISA coprocessor support" }, /* PNP0C04 */
@@ -1048,4 +1048,5 @@ static driver_t npxisa_driver = {
static devclass_t npxisa_devclass;
DRIVER_MODULE(npxisa, isa, npxisa_driver, npxisa_devclass, 0, 0);
+DRIVER_MODULE(npxisa, acpi, npxisa_driver, npxisa_devclass, 0, 0);
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
- * This sucks up the legacy ISA support assignments from PNPBIOS.
+ * This sucks up the legacy ISA support assignments from PNPBIOS/ACPI.
*/
static struct isa_pnp_id npxisa_ids[] = {
diff --git a/sys/amd64/isa/npx.c b/sys/amd64/isa/npx.c
index a246f30..4fe3d04 100644
--- a/sys/amd64/isa/npx.c
+++ b/sys/amd64/isa/npx.c
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
* This sucks up the legacy ISA support assignments from PNPBIOS.
*/
static struct isa_pnp_id npxisa_ids[] = {
{ 0x040cd041, "Legacy ISA coprocessor support" }, /* PNP0C04 */
@@ -1048,4 +1048,5 @@ static driver_t npxisa_driver = {
static devclass_t npxisa_devclass;
DRIVER_MODULE(npxisa, isa, npxisa_driver, npxisa_devclass, 0, 0);
+DRIVER_MODULE(npxisa, acpi, npxisa_driver, npxisa_devclass, 0, 0);
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
- * This sucks up the legacy ISA support assignments from PNPBIOS.
+ * This sucks up the legacy ISA support assignments from PNPBIOS/ACPI.
*/
static struct isa_pnp_id npxisa_ids[] = {
diff --git a/sys/i386/isa/npx.c b/sys/i386/isa/npx.c
index a246f30..4fe3d04 100644
--- a/sys/i386/isa/npx.c
+++ b/sys/i386/isa/npx.c
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
* This sucks up the legacy ISA support assignments from PNPBIOS.
*/
static struct isa_pnp_id npxisa_ids[] = {
{ 0x040cd041, "Legacy ISA coprocessor support" }, /* PNP0C04 */
@@ -1048,4 +1048,5 @@ static driver_t npxisa_driver = {
static devclass_t npxisa_devclass;
DRIVER_MODULE(npxisa, isa, npxisa_driver, npxisa_devclass, 0, 0);
+DRIVER_MODULE(npxisa, acpi, npxisa_driver, npxisa_devclass, 0, 0);
@@ -1004,7 +1004,7 @@ static devclass_t npx_devclass;
DRIVER_MODULE(npx, nexus, npx_driver, npx_devclass, 0, 0);
/*
- * This sucks up the legacy ISA support assignments from PNPBIOS.
+ * This sucks up the legacy ISA support assignments from PNPBIOS/ACPI.
*/
static struct isa_pnp_id npxisa_ids[] = {